/*
 * Copyright (C) 2008-2010 by CERN
 *
 * Authors: Zsolt Molnar <zsolt.molnar@cern.ch, http://www.zsoltmolnar.hu>
 *
 * Objects for dependency injection of SRM services.
 * (see: http://en.wikipedia.org/wiki/Dependency_injection)
 *
 * The goal: make the LCG_Util logic unit-testable by decoupling from the real Globus
 * calls. Unit tests then create mock objects and create response objects
 * without real Globus / network operations.
 */

/*
 * @(#)$RCSfile: globus_dependencies.h,v $ $Revision: 1.1 $ $Date: 2009/11/18 13:53:33 $ CERN Remi Mollon
 */
#ifndef LCG_GLOBUS_DEPENDENCIES_H__
#define LCG_GLOBUS_DEPENDENCIES_H__

#include "lcg_util.h"

/* enforce proper calling convention */
#ifdef __cplusplus
extern "C"
{
#endif

/* Function types of the appropriate SOAP calls */
typedef int (*lcg_globus_copyfilex_fv)(
    char *src_file, char *dest_file, int nbstreams, char *errbuf,
    int errbufsz, int timeout, int verbose);

typedef int (*lcg_globus_getfilesizet_fv)(
    char *file, GFAL_LONG64 *size, char *errbuf, int errbufsz, int timeout);

/* The collection of Globus calls. The pointers may be replaced with test
 * functions (dependency injection) */
typedef struct lcg_globus_callers {
    lcg_globus_copyfilex_fv call_globus_copyfilex;
    lcg_globus_getfilesizet_fv call_globus_getfilesizet;
} lcg_globus_callers_t;

extern lcg_globus_callers_t lcg_globus_functions;

#ifdef __cplusplus
}
#endif

#endif /* #ifndef LCG_GLOBUS_DEPENDENCIES_H__ */
