/*
 * Copyright (C) 2005 by CERN
 * All rights reserved
 */

#ifndef lint
static char sccsid[] = "@(#)$RCSfile: lcg_lg.c,v $ $Revision: 1.17 $ $Date: 2008/11/10 12:38:16 $ CERN Jean-Philippe Baud";
#endif /* not lint */

/*	lcg_lg - get the GUID for a given LFN or SURL */
#include <errno.h>
#include <stdlib.h>
#include <string.h>
#include "gfal_api.h"
#include "lcg_util.h"

lcg_lg (char *file, char *vo, char *conf_file, int insecure, char *guid)
{
	return (lcg_lg2 (file, 0, vo, guid, NULL, 0));
}

lcg_lgx (char *file, char *vo, char *conf_file, int insecure, char *guid,
	char *errbuf, int errbufsz)
{
	return (lcg_lg2 (file, 0, vo, guid, errbuf, errbufsz));
}

lcg_lg2 (char *file, int nobdii, char *vo, char *guid, char *errbuf, int errbufsz)
{
	char *actual_guid;
	char actual_file[GFAL_PATH_MAXLEN];

	if (file == NULL || guid == NULL) {
		errno = EFAULT;
		return (-1);
	}
	if (vo && vo[0]) {
		if (strlen (vo) > GFAL_VO_MAXLEN) {
			gfal_errmsg (errbuf, errbufsz, GFAL_ERRLEVEL_ERROR, "VO name too long.");
			errno = ENAMETOOLONG;
			return (-1);
		}
		if (gfal_set_vo (vo) < 0)
			return (-1);
	}

	if (canonical_url (file, NULL, actual_file, GFAL_PATH_MAXLEN, errbuf, GFAL_ERRMSG_LEN) < 0)
		return (-1);

	gfal_set_nobdii (nobdii);

	if (strncmp (actual_file, "lfn:", 4) == 0) {
		if ((actual_guid = guidfromlfn (actual_file + 4, errbuf, errbufsz)) == NULL)
			return (-1);
	} else if (strncmp (actual_file, "srm:", 4) == 0 || strncmp (actual_file, "sfn:", 4) == 0) {
		if ((actual_guid = gfal_guidforpfn (actual_file, errbuf, errbufsz)) == NULL)
			return (-1);
	} else {
		gfal_errmsg (errbuf, errbufsz, GFAL_ERRLEVEL_ERROR,
				"%s: File starts with neither \"lfn:\", \"srm:\" nor \"sfn:\".", file);
		errno = EINVAL;
		return (-1);
	}
	strcpy (guid, actual_guid);
	free (actual_guid);
	return (0);
}
