#! /bin/bash

# Collection of test commands for Savannah bug #54872: 
#   lcg_util: should use -1 length for gridftp/CKSM
#
# https://savannah.cern.ch/bugs/?54872
#
# See test instructions there.

# DPM
#
# - upload a file. No checksum is calculated and stored in this case.
# - call srmLs, to verify that there is no checksum returned (as it is not stored).
# - call lcg-get-checksum to trigger checksum calculation and storing. It displays
#   the checksum.
# - call srmls again, it should display the checksum now, and must be equal to
#   the value in the previous point.
FILE="srm://vmgdda0013.cern.ch:8446/srm/managerv2?SFN=/dpm/cern.ch/home/dteam/a41.dat"
glite-url-copy -b -d -C file:///etc/redhat-release $FILE
lcg-ls -lvbD srmv2 $FILE
lcg-get-checksum -bD srmv2 -v $FILE
lcg-ls -lvbD srmv2 $FILE
lcg-del -lvbD srmv2 $FILE

# dCache
# After uploading the file, the checksum is calculated and stored.
#
# - upload a file. Checksum is calculated and stored.
# - call srmLs, it returns the checksum for the whole file.
# - call lcg-get-checksum. The checksum value should be the same like above.
FILE="srm://srm-devel.desy.de:8443/srm/managerv2?SFN=/pnfs/desy.de/data/dteam/a41.dat"
glite-url-copy -b -d -C file:///etc/redhat-release $FILE
lcg-ls -lvbD srmv2 $FILE
lcg-get-checksum -bD srmv2 -v $FILE
lcg-del -lvbD srmv2 $FILE