/*
 * Authors: Zsolt Molnar <zsolt.molnar@cern.ch, http://www.zsoltmolnar.hu>
 *
 * Copyright (C) 2009 by CERN
 * All rights reserved
 */
#include "lcg_util.h"
#include "lcg_unit_testsuite.h"

/** Do not worry about the memory leaks in this sw :) (we free nothing) */
char * lcg_test__lcg_tokenize()
{
    char** res = NULL;
    /* NULL parameters should be handled properly */
    res = lcg_tokenize(NULL, NULL);
    LCG_TEST_ASSERT(res == NULL);
    res = lcg_tokenize(NULL, ",");
    LCG_TEST_ASSERT(res == NULL);
    res = lcg_tokenize("a,b", NULL);
    LCG_TEST_ASSERT(res == NULL);
    /* Test simple tokenizing */
    res = lcg_tokenize("a,b,c", ",");
    LCG_TEST_ASSERT(res != NULL);
    LCG_TEST_ASSERT(strcmp(res[0], "a") == 0);
    LCG_TEST_ASSERT(strcmp(res[1], "b") == 0);
    LCG_TEST_ASSERT(strcmp(res[2], "c") == 0);
    LCG_TEST_ASSERT(res[3] == NULL);
    /* Test tokenizing with multiple separators */
    res = lcg_tokenize("a,b;c", ",;");
    LCG_TEST_ASSERT(res != NULL);
    LCG_TEST_ASSERT(strcmp(res[0], "a") == 0);
    LCG_TEST_ASSERT(strcmp(res[1], "b") == 0);
    LCG_TEST_ASSERT(strcmp(res[2], "c") == 0);
    LCG_TEST_ASSERT(res[3] == NULL);
    /* Test tokenizing with empty string */
    res = lcg_tokenize("a,b;c", "");
    LCG_TEST_ASSERT(res != NULL);
    LCG_TEST_ASSERT(strcmp(res[0], "a,b;c") == 0);
    LCG_TEST_ASSERT(res[1] == NULL);
    /* Test tokenizing of empty string */
    res = lcg_tokenize("", ",;");
    LCG_TEST_ASSERT(res != NULL);
    LCG_TEST_ASSERT(res[0] == NULL);
    /* Test the not existing separator case */
    res = lcg_tokenize("a,b;c", "=");
    LCG_TEST_ASSERT(res != NULL);
    LCG_TEST_ASSERT(strcmp(res[0], "a,b;c") == 0);
    LCG_TEST_ASSERT(res[1] == NULL);
    return NULL;
}
