/*
 * Authors: Zsolt Molnar <zsolt.molnar@cern.ch, http://www.zsoltmolnar.hu>
 *
 * Copyright (C) 2009 by CERN
 * All rights reserved
 */

 #include <stdio.h>
#include "lcg_unit_testsuite.h"

int __lcg_tests_run = 0;

/* Example test suite
 *
 * 1. Create a test function. Signature should follow the example.
 *
 * char * test_foo()
 * {
 *     LCG_TEST_ASSERT(1);
 *     return 0;
 * }
 *
 * Use the LCG_TEST_ASSERT macro. Its parameter must be a boolean value. If
 * it is false, the test suite stops immediately, with an error message.
 *
 * List all the test functions here, in this file.
 *
 * 2. Add the test function to the lcg_all_tests, in the following way:
 *
 * static char * lcg_all_tests()
 * {
 *     LCG_TEST_RUN(test_foo);
 *     return NULL;
 * }
 *
 * 3. Do not forget updating the Makefile.am, if you add new sources...
 *
 * That is it.
 */

/*
 * List of test functions
 */
char * lcg_test__lcg_tokenize();
char * lcg_test__protocol_list_handling();
char * lcg_test__60334_lcg_cp_hangs_when_file_has_no_replica();
char * lcg_test__60991_lcg_cr();

/*
 * Register the test functions here
 */
static char * lcg_all_tests()
{
    LCG_TEST_RUN(lcg_test__lcg_tokenize);
    LCG_TEST_RUN(lcg_test__protocol_list_handling);
    LCG_TEST_RUN(lcg_test__60334_lcg_cp_hangs_when_file_has_no_replica);
    LCG_TEST_RUN(lcg_test__60991_lcg_cr);
    return NULL;
}

int main(int argc, char **argv)
{
    char *result = NULL;
    printf("Starting LCG_Util unit test suite...\n\n");
    result = lcg_all_tests();

    if (result) {
        printf("%s\n", result);
    } else {
        printf("\nALL TESTS PASSED.\n");
    }

    printf("Test functions executed: %d\n", __lcg_tests_run);
    /* Must return 0 in case of successful executing */
    return result != NULL;
}
