/*
 * Authors: Zsolt Molnar <zsolt.molnar@cern.ch, http://www.zsoltmolnar.hu>
 *
 * Copyright (C) 2009 by CERN
 * All rights reserved
 *
 * Inspired by MinUnit -- a minimal unit testing framework for C
 * (http://www.jera.com/techinfo/jtns/jtn002.html)
 */
#ifndef LCG_UNIT_TESTSUITE_H
#define LCG_UNIT_TESTSUITE_H

#include <stdio.h>
#include <stdlib.h>

#define LCG_TEST_ASSERT(test) \
    do { \
        printf("\t Test at %s:%d... ", __FILE__, __LINE__); \
        if (!(test)) { \
            printf("FAILED\n"); \
            exit(-1); \
        } \
        printf("OK\n"); \
    } while (0)

#define LCG_TEST_EQUAL(expected, value) \
    do { \
        printf("\t Test at %s:%d... ", __FILE__, __LINE__); \
        if ((expected) != (value)) { \
            printf("FAILED. Expected: %d, Got: %d\n", (expected), (value)); \
            exit(-1); \
        } \
        printf("OK\n"); \
    } while (0)

#define LCG_TEST_RUN(test) \
    do { \
        char *message = NULL; \
        printf("Running: %s...\n", #test); \
        message = test(); \
        __lcg_tests_run++; \
        if (message) \
            return message; \
       } while (0)

extern int __lcg_tests_run;

#endif /* #ifndef LCG_UNIT_TESTSUITE_H */
